@@ -1,7 +1,7 @@
 import ctypes
 import time
 
-user32 = ctypes.WinDLL('user32', use_last_error=True)
+user32 = ctypes.WinDLL("user32", use_last_error=True)
 
 
 def action(code, mod):
